==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/lt-LT/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Priedas paimtas',
    'Accessory_Checkout_Notification' => 'Priedas išduotas',
    'Asset_Checkin_Notification' => 'Turtas paimtas',
    'Asset_Checkout_Notification' => 'Turtas išduotas',
    'Confirm_Accessory_Checkin' => 'Priedo paėmimo patvirtinimas',
    'Confirm_Asset_Checkin' => 'Turto paėmimo patvirtinimas',
    'Confirm_accessory_delivery' => 'Priedo pristatymo patvirtinimas',
    'Confirm_asset_delivery' => 'Turto pristatymo patvirtinimas',
    'Confirm_consumable_delivery' => 'Eksploatacinės medžiagos pristatymo patvirtinimas',
    'Confirm_license_delivery' => 'Licencijos pristatymo patvirtinimas',
    'Consumable_checkout_notification' => 'Eksploatacinė medžiaga išduota',
    'Days' => 'Dienos',
    'Expected_Checkin_Date' => 'Jums yra išduotas turtas, kuris bus iš jūsų paimtas :date d.',
    'Expected_Checkin_Notification' => 'Priminimas: artėja :name paėmimo terminas',
    'Expected_Checkin_Report' => 'Numatomo paimti turto ataskaita',
    'Expiring_Assets_Report' => 'Bebaigiančio galioti turto ataskaita.',
    'Expiring_Licenses_Report' => 'Bebaigiančių galioti licencijų ataskaita.',
    'Item_Request_Canceled' => 'Daikto užsakymas atšauktas',
    'Item_Requested' => 'Daiktas užsakytas',
    'License_Checkin_Notification' => 'Licencija paimta',
    'License_Checkout_Notification' => 'Licencija išduota',
    'Low_Inventory_Report' => 'Ataskaita apie mažas atsargas',
    'a_user_canceled' => 'Naudotojas svetainėje atšaukė daikto užsakymą',
    'a_user_requested' => 'Naudotojas svetainėje užsakė daiktą',
    'acceptance_asset_accepted' => 'Naudotojas priėmė daiktą',
    'acceptance_asset_declined' => 'Naudotojas nepriėmė daikto',
    'accessory_name' => 'Priedo pavadinimas',
    'additional_notes' => 'Papildomos pastabos',
    'admin_has_created' => 'Administratorius sukūrė jums paskyrą :web svetainėje.',
    'asset' => 'Turtas',
    'asset_name' => 'Turto pavadinimas',
    'asset_requested' => 'Turtas užsakytas',
    'asset_tag' => 'Inventorinis numeris',
    'assets_warrantee_alert' => 'Yra :count turto vienetas, kurio garantija baigiasi per kitas :threshold dienas (-ų).|Yra :count turto vienetai (-ų), kurių garantija baigiasi per kitas :threshold dienas (-ų).',
    'assigned_to' => 'Išduota',
    'best_regards' => 'Pagarbiai,',
    'canceled' => 'Atšauktas',
    'checkin_date' => 'Paėmimo data',
    'checkout_date' => 'Išdavimo data',
    'checkedout_from' => 'Išduota iš',
    'checkedin_from'  => 'Paimta iš',
    'checked_into' => 'Paimta į',
    'click_on_the_link_accessory' => 'Spustelėkite nuorodą apačioje, kad patvirtintumėte, jog gavote priedą.',
    'click_on_the_link_asset' => 'Spustelėkite nuorodą apačioje, kad patvirtintumėte, jog gavote turtą.',
    'click_to_confirm' => 'Spustelėkite šią nuorodą, kad patvirtintumėte savo :web paskyrą:',
    'current_QTY' => 'Esamas kiekis',
    'days' => 'Dienos',
    'expecting_checkin_date' => 'Numatoma paėmimo data',
    'expires' => 'Baigia galioti',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Aš perskaičiau ir sutinku su naudojimo sąlygomis, ir patvirtinu, kad gavau šį daiktą.',
    'inventory_report' => 'Inventoriaus ataskaita',
    'item' => 'Daiktas',
    'item_checked_reminder' => 'Tai priminimas, kad šiuo metu jums yra išduoti :count daiktai, kurių nepriėmėte arba neatmetėte. Spustelėkite toliau pateiktą nuorodą, kad patvirtintumėte savo sprendimą.',
    'license_expiring_alert' => 'Yra :count licencija, kuri baigiasi per kitas :threshold dienas.|Yra :count licencijos (-ų), kurios baigiasi per kitas :threshold dienas (-ų).',
    'link_to_update_password' => 'Spustelėkite šią nuorodą, kad atnaujintumėte savo :web slaptažodį:',
    'login' => 'Prisijungti:',
    'login_first_admin' => 'Prisijunkite prie savo naujojo „Snipe-IT“ diegimo naudodami žemiau pateiktus prisijungimo duomenis:',
    'low_inventory_alert' => 'Yra :count daiktas, kurio atsargos yra mažesnės (arba greitais bus mažesnės) nei numatytos minimalios atsargos.|Yra :count daiktai (-ų), kurių atsargos yra mažesnės (arba greitais bus mažesnės) nei numatytos minimalios atsargos.',
    'min_QTY' => 'Min. kiekis',
    'name' => 'Pavadinimas',
    'new_item_checked' => 'Jums buvo priskirtas naujas daiktas, išsami informacija pateikta žemiau.',
    'notes' => 'Pastabos',
    'password' => 'Slaptažodis',
    'password_reset' => 'Slaptažodžio nustatymas iš naujo',
    'read_the_terms' => 'Perskaitykite žemiau pateiktas naudojimo sąlygas.',
    'read_the_terms_and_click' => 'Perskaitykite žemiau pateiktas naudojimo sąlygas ir spustelėti apačioje esančią nuorodą, kad patvirtintumėte jog perskaitėte ir sutinkate su jomis, bei kad gavote turtą.',
    'requested' => 'Užsakytas',
    'reset_link' => 'Jūsų slaptažodžio nustatymo iš naujo nuoroda',
    'reset_password' => 'Spustelėkite čia norėdami iš naujo nustatyti slaptažodį:',
    'rights_reserved' => 'Visos teisės saugomos.',
    'serial' => 'Serijinis numeris',
    'snipe_webhook_test' => 'Snipe-IT integracijos testas',
    'snipe_webhook_summary' => 'Snipe-IT integracijos testo suvestinė',
    'supplier' => 'Tiekėjas',
    'tag' => 'Žyma',
    'test_email' => 'Bandomasis laiškas iš „Snipe-IT“',
    'test_mail_text' => 'Tai yra „Snipe-IT“ turto valdymo sistemos testas. Jei gavote šį pranešimą, vadinasi paštas veikia.',
    'the_following_item' => 'Šis daiktas buvo paimtas: ',
    'to_reset' => 'Norėdami iš naujo nustatyti savo :web slaptažodį, užpildykite šią formą:',
    'type' => 'Tipas',
    'upcoming-audits' => 'Yra :count turto vienetas, kuriam per :threshold dienas (-ų) turi būti atliktas auditas.|Yra :count turto vienetai (-ų), kuriems per :threshold dienas (-ų) turi būti atliktas auditas.',
    'user' => 'Naudotojas',
    'username' => 'Naudotojo vardas',
    'unaccepted_asset_reminder' => 'Turite nepriimto turto.',
    'welcome' => 'Sveiki, :name',
    'welcome_to' => 'Sveiki apsilankę :web!',
    'your_assets' => 'Peržiūrėti jūsų turtą',
    'your_credentials' => 'Jūsų „Snipe-IT“ prisijungimo duomenys',
    'mail_sent' => 'Laiškas sėkmingai išsiųstas!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/lt-LT/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Priedas paimtas',
    'Accessory_Checkout_Notification' => 'Priedas išduotas',
    'Asset_Checkin_Notification' => 'Turtas paimtas',
    'Asset_Checkout_Notification' => 'Turtas išduotas',
    'Confirm_Accessory_Checkin' => 'Priedo paėmimo patvirtinimas',
    'Confirm_Asset_Checkin' => 'Turto paėmimo patvirtinimas',
    'Confirm_accessory_delivery' => 'Priedo pristatymo patvirtinimas',
    'Confirm_asset_delivery' => 'Turto pristatymo patvirtinimas',
    'Confirm_consumable_delivery' => 'Eksploatacinės medžiagos pristatymo patvirtinimas',
    'Confirm_license_delivery' => 'Licencijos pristatymo patvirtinimas',
    'Consumable_checkout_notification' => 'Eksploatacinė medžiaga išduota',
    'Days' => 'Dienos',
    'Expected_Checkin_Date' => 'Jums yra išduotas turtas, kuris bus iš jūsų paimtas :date d.',
    'Expected_Checkin_Notification' => 'Priminimas: artėja :name paėmimo terminas',
    'Expected_Checkin_Report' => 'Numatomo paimti turto ataskaita',
    'Expiring_Assets_Report' => 'Bebaigiančio galioti turto ataskaita.',
    'Expiring_Licenses_Report' => 'Bebaigiančių galioti licencijų ataskaita.',
    'Item_Request_Canceled' => 'Daikto užsakymas atšauktas',
    'Item_Requested' => 'Daiktas užsakytas',
    'License_Checkin_Notification' => 'Licencija paimta',
    'License_Checkout_Notification' => 'Licencija išduota',
    'license_for'   => 'Licencija skirta',
    'Low_Inventory_Report' => 'Ataskaita apie mažas atsargas',
    'a_user_canceled' => 'Naudotojas svetainėje atšaukė daikto užsakymą',
    'a_user_requested' => 'Naudotojas svetainėje užsakė daiktą',
    'acceptance_asset_accepted' => 'Naudotojas priėmė daiktą',
    'acceptance_asset_declined' => 'Naudotojas nepriėmė daikto',
    'accessory_name' => 'Priedo pavadinimas',
    'additional_notes' => 'Papildomos pastabos',
    'admin_has_created' => 'Administratorius sukūrė jums paskyrą :web svetainėje.',
    'asset' => 'Turtas',
    'asset_name' => 'Turto pavadinimas',
    'asset_requested' => 'Turtas užsakytas',
    'asset_tag' => 'Inventorinis numeris',
    'assets_warrantee_alert' => 'Yra :count turto vienetas, kurio garantija baigiasi per kitas :threshold dienas (-ų).|Yra :count turto vienetai (-ų), kurių garantija baigiasi per kitas :threshold dienas (-ų).',
    'assigned_to' => 'Išduota',
    'best_regards' => 'Pagarbiai,',
    'canceled' => 'Atšauktas',
    'checkin_date' => 'Paėmimo data',
    'checkout_date' => 'Išdavimo data',
    'checkedout_from' => 'Išduota iš',
    'checkedin_from'  => 'Paimta iš',
    'checked_into' => 'Paimta į',
    'click_on_the_link_accessory' => 'Spustelėkite nuorodą apačioje, kad patvirtintumėte, jog gavote priedą.',
    'click_on_the_link_asset' => 'Spustelėkite nuorodą apačioje, kad patvirtintumėte, jog gavote turtą.',
    'click_to_confirm' => 'Spustelėkite šią nuorodą, kad patvirtintumėte savo :web paskyrą:',
    'current_QTY' => 'Esamas kiekis',
    'days' => 'Dienos',
    'expecting_checkin_date' => 'Numatoma paėmimo data',
    'expires' => 'Baigia galioti',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Aš perskaičiau ir sutinku su naudojimo sąlygomis, ir patvirtinu, kad gavau šį daiktą.',
    'inventory_report' => 'Inventoriaus ataskaita',
    'item' => 'Daiktas',
    'item_checked_reminder' => 'Tai priminimas, kad šiuo metu jums yra išduoti :count daiktai, kurių nepriėmėte arba neatmetėte. Spustelėkite toliau pateiktą nuorodą, kad patvirtintumėte savo sprendimą.',
    'license_expiring_alert' => 'Yra :count licencija, kuri baigiasi per kitas :threshold dienas.|Yra :count licencijos (-ų), kurios baigiasi per kitas :threshold dienas (-ų).',
    'link_to_update_password' => 'Spustelėkite šią nuorodą, kad atnaujintumėte savo :web slaptažodį:',
    'login' => 'Prisijungti',
    'login_first_admin' => 'Prisijunkite prie savo naujojo „Snipe-IT“ diegimo naudodami žemiau pateiktus prisijungimo duomenis:',
    'low_inventory_alert' => 'Yra :count daiktas, kurio atsargos yra mažesnės (arba greitais bus mažesnės) nei numatytos minimalios atsargos.|Yra :count daiktai (-ų), kurių atsargos yra mažesnės (arba greitais bus mažesnės) nei numatytos minimalios atsargos.',
    'min_QTY' => 'Mažiausias kiekis',
    'name' => 'Pavadinimas',
    'new_item_checked' => 'Jums buvo priskirtas naujas daiktas, išsami informacija pateikta žemiau.',
    'notes' => 'Pastabos',
    'password' => 'Slaptažodis',
    'password_reset' => 'Slaptažodžio nustatymas iš naujo',
    'read_the_terms' => 'Perskaitykite žemiau pateiktas naudojimo sąlygas.',
    'read_the_terms_and_click' => 'Perskaitykite žemiau pateiktas naudojimo sąlygas ir spustelėti apačioje esančią nuorodą, kad patvirtintumėte jog perskaitėte ir sutinkate su jomis, bei kad gavote turtą.',
    'requested' => 'Užsakytas',
    'reset_link' => 'Jūsų slaptažodžio nustatymo iš naujo nuoroda',
    'reset_password' => 'Spustelėkite čia norėdami iš naujo nustatyti slaptažodį:',
    'rights_reserved' => 'Visos teisės saugomos.',
    'serial' => 'Serijinis numeris',
    'snipe_webhook_test' => 'Snipe-IT integracijos testas',
    'snipe_webhook_summary' => 'Snipe-IT integracijos testo suvestinė',
    'supplier' => 'Tiekėjas',
    'tag' => 'Žyma',
    'test_email' => 'Bandomasis laiškas iš „Snipe-IT“',
    'test_mail_text' => 'Tai yra „Snipe-IT“ turto valdymo sistemos testas. Jei gavote šį pranešimą, vadinasi paštas veikia.',
    'the_following_item' => 'Šis daiktas buvo paimtas: ',
    'to_reset' => 'Norėdami iš naujo nustatyti savo :web slaptažodį, užpildykite šią formą:',
    'type' => 'Tipas',
    'upcoming-audits' => 'Yra :count turto vienetas, kuriam per :threshold dienas (-ų) turi būti atliktas auditas.|Yra :count turto vienetai (-ų), kuriems per :threshold dienas (-ų) turi būti atliktas auditas.',
    'user' => 'Naudotojas',
    'username' => 'Naudotojo vardas',
    'unaccepted_asset_reminder' => 'Turite nepriimto turto.',
    'welcome' => 'Sveiki, :name',
    'welcome_to' => 'Sveiki apsilankę :web!',
    'your_assets' => 'Peržiūrėti jūsų turtą',
    'your_credentials' => 'Jūsų „Snipe-IT“ prisijungimo duomenys',
    'mail_sent' => 'Laiškas sėkmingai išsiųstas!',
];
